server/sources/__init__.py
changeset 6724 24bf6f181d0e
parent 6722 3341521d857b
child 6931 0af44a38fe41
--- a/server/sources/__init__.py	Wed Dec 01 17:09:19 2010 +0100
+++ b/server/sources/__init__.py	Wed Dec 01 17:11:35 2010 +0100
@@ -116,8 +116,10 @@
         """method called by the repository once ready to create a new instance"""
         pass
 
-    def init(self):
-        """method called by the repository once ready to handle request"""
+    def init(self, activated, session=None):
+        """method called by the repository once ready to handle request.
+        `activated` is a boolean flag telling if the source is activated or not.
+        """
         pass
 
     def backup(self, backupfile, confirm):
@@ -146,7 +148,7 @@
         pass
 
     def __repr__(self):
-        return '<%s source @%#x>' % (self.uri, id(self))
+        return '<%s source %s @%#x>' % (self.uri, self.eid, id(self))
 
     def __cmp__(self, other):
         """simple comparison function to get predictable source order, with the